import { SerializedJSONValue } from '@contentful/app-sdk';
export type UseFieldValueReturnValue<Value = unknown> = [
    value: Value | undefined,
    setValue: (newValue: Value | undefined) => Promise<SerializedJSONValue | undefined>
];
/**
 * Returns field value and a function to update it.
 * Must be wrapped by SDKProvider.
 * Can only be used when app is rendered in field, sidebar or entry editor location.
 *
 * @param {string=} fieldId Id of the field to read and update. Can be omitted when app is rendered in field location.
 * @param {string=} locale Locale to read and update. When omitted, default locale is used.
 * @returns {UseFieldValueReturnValue} Field value, function to update it
 */
export declare function useFieldValue<Value = unknown>(fieldId?: string, locale?: string): UseFieldValueReturnValue<Value>;
